#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
@file
@brief This script performs image modification and processing based on configurations specified in the "config_left.ini" or "config_right.ini" file.

@details
The script utilizes the following classes:
- `MaskCreator`: Responsible for creating masks and applying image modifications.
- `ConfigReader`: Reads configuration settings from the specified configuration file ("config_left.ini" or "config_right.ini").
- `MainDisplay`: Handles the main display functionalities.

@note
Make sure to change the configuration file path (`CReader = ConfigReader("config_left.ini")`) accordingly based on the image side.

@date January 18, 2024
"""

from MaskCreator import MaskCreator
from ConfigReader import ConfigReader
from MainDisplay import MainDisplay

# creating object for MainDisplay, ConfigReader classes

# change to config_left.ini or config_right.ini when necessary
CReader = ConfigReader("config_left.ini")
# CReader = ConfigReader("config_right.ini")
MDisplay = MainDisplay()

# initializing variables
mask_width = CReader.getProjectedOverlapWidth()
image_width = CReader.getProjectedImageWidth()
gamma = CReader.getGamma()
image_side = CReader.getImageSide()
image_path = CReader.getImageName()

if image_side == 0:
    image_name = 'left'
elif image_side == 1:
    image_name = 'right'
else:
    print("Invalid ImageSide value in config.ini. Use 0 for left image, 1 for right image.")

# loading image
image = MDisplay.readImage(image_path)
result_image = MDisplay.setImage(image)

if image is not None:
    # creating object for MaskCreator class
    MCreator = MaskCreator(image)
    
    # image modification
    MCreator.create_mask(image_side, mask_width, image_width)
    MCreator.gammaCorrection(gamma)
    MCreator.result_image = result_image
    MCreator.alpha_blending(image_side)
    MCreator.mod_intensity(image_side)
    
    # saving image
    MDisplay.saveImage()
else:
    print(f"Failed to read the image (ImageSide={image_side}).")